| 50 | } |
| 51 | |
| 52 | void launch_param_update(const float* input, sycl::half* output, int size, sycl::queue* stream) |
| 53 | { |
| 54 | int threads = 1024; |
| 55 | |
| 56 | sycl::range<3> grid_dim(1, 1, (size - 1) / threads + 1); |
| 57 | sycl::range<3> block_dim(1, 1, threads); |
| 58 | |
| 59 | { |
| 60 | has_capability_or_fail(stream->get_device(), {sycl::aspect::fp16}); |
| 61 | stream->parallel_for( |
| 62 | sycl::nd_range<3>(grid_dim * block_dim, block_dim), |
| 63 | [=](sycl::nd_item<3> item_ct1) { param_update_kernel(input, output, size); }); |
| 64 | } |
| 65 | } |
| 66 | |
| 67 | void param_update_kernel_half(const float* input, sycl::half* output, int size) |
| 68 | { |
nothing calls this directly
no test coverage detected